#
# spec file
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2013 LISA GmbH, Bingen, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif
Name:           python-zope.component%{psuffix}
VCS: https://src.suse.de/SLFO-pool/python-zope.component#c994842c911cb0c5129d8647361499784ae8ab225423a0429db0e31369500883
Version:        6.0
Release:        160000.1.12
Summary:        Zope Component Architecture
License:        ZPL-2.1
Group:          Development/Languages/Python
URL:            https://github.com/zopefoundation/zope.component
Source:         https://files.pythonhosted.org/packages/source/z/zope.component/zope.component-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-zope.event
Requires:       python-zope.hookable >= 4.2.0
Requires:       python-zope.interface >= 5.3.0a1
#test requirements
%if %{with test}
BuildRequires:  %{python_module persistent}
BuildRequires:  %{python_module zope.deferredimport}
BuildRequires:  %{python_module zope.hookable}
BuildRequires:  %{python_module zope.interface}
BuildRequires:  %{python_module zope.location}
BuildRequires:  %{python_module zope.proxy}
BuildRequires:  %{python_module zope.security}
BuildRequires:  %{python_module zope.testing}
BuildRequires:  %{python_module zope.testrunner}
%endif
%python_subpackages

%description
This package is intended to be independently reusable in any Python project. It
is maintained by the Zope Toolkit project.

This package represents the core of the Zope Component Architecture. Together
with the 'zope.interface' package, it provides facilities for defining,
registering and looking up components.

Please see http://docs.zope.org/zope.component/ or doc package for the
documentation.

%prep
%setup -q -n zope.component-%{version}
rm -rf src/zope.component.egg-info

%build
%python_build

%install
%if !%{with test}
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%if %{with test}
%check
%python_expand PYTHONPATH=src %{_bindir}/zope-testrunner-%{$python_bin_suffix} -vvv --test-path src
%endif

%if !%{with test}
%files %{python_files}
%defattr(-,root,root)
%license LICENSE.txt COPYRIGHT.txt
%doc CHANGES.rst README.rst
%{python_sitelib}/*
%endif

%changelog
* Fri May  5 2023 dmueller@suse.com
- update to 6.0:
  * Drop support for Python 2.7, 3.5, 3.6.
  * Fix crash when the environment variable `PYTHONOPTIMIZED` is
    set to `2` and docstrings are set to `None` by the interpreter.
  * Add support for Python 3.10 and 3.11.
* Sat Jul 10 2021 os@jacraig.com
- Update to 5.0.1
  * Add support for Python 3.9.
  * Many other changes, see CHANGES.rst
- Update requirements as changed in setup.py.
- Mark LICENSE.txt, COPYRIGHT.txt with %%license.
* Tue Jul 21 2020 mcalabkova@suse.com
- update to version 4.6.2
  * Improve the documentation, both published and in docstrings.
* Thu Apr  2 2020 pgajdos@suse.com
- version update to 4.6.1
  - Ensure the resolution order of ``BaseGlobalComponents`` is
  consistent. See `issue 45 <https://github.com/zopefoundation/zope.component/issues/45>`_.
* Tue Jan 21 2020 mcalabkova@suse.com
- update to version 4.6
  * Add support for Python 3.8.
  * Drop support for Python 3.4.
  * Fix tests on Python 2 following changes in ZODB 5.5.0.
* Mon Apr  8 2019 mcalabkova@suse.com
- update to version 4.5
  * Add support for Python 3.6 and 3.7.
  * Drop support for Python 3.3.
  * Drop support for “setup.py test”.
  * Always install zope.hookable as a dependency.
  * Make accessing names that have been moved to zope.interface
    produce a DeprecationWarning.
- Drop the *-doc subpackage, use multibuild instead.
  * Drop pre-checkin.sh as it is no longer needed.
* Sun Jul 16 2017 aloisio@gmx.com
- Update to version 4.3.0
  * When testing PURE_PYTHON environments under tox, avoid
    poisoning the user’s global wheel cache.
  * Drop support for Python 2.6 and 3.2.
  * Add support for Python 3.5.
  4.2.2:
  * Fix test cases for PyPy and PyPy3.
- Split docs and tests into separate package to avoid dependency
  loop.
- Converted to single-spec
* Fri May 15 2015 benoit.monin@gmx.fr
- update to version 4.2.1:
  * Added support for Python 3.4.
- switch source archive to tar.gz (zip not available)
- remove unzip from BuildRequires
* Wed Feb 19 2014 os-dev@jacraig.com
- Update to 4.2.0:
  * Updated ``boostrap.py`` to version 2.2.
  * Reset the cached ``adapter_hooks`` at ``zope.testing.cleanup.cleanUp``
    time (LP1100501).
  * Implemented ability to specify adapter and utility names in Python. Use
    the ``@zope.component.named(name)`` decorator to specify the name.
- Update python-zope.interface requirement version (see setup.py).
* Tue Dec 10 2013 p.drouand@gmail.com
- Use download Url as source
- Add unzip requirement to support tarball format
* Wed Jul 31 2013 hpj@urpla.net
- disable testing due to circular dependency with python-zope.security
* Mon Jul 29 2013 hpj@urpla.net
- version 4.1.0: initial build
